@@ -1,4 +1,4 @@
-import numpy as N
+import numpy as np
 import matplotlib
 # -*- coding: iso-8859-1 -*-
 
@@ -65,7 +65,7 @@ def get_distinct(nr):
 
 # Deviation around zero colormap (blue--red)
 cols = []
-for x in N.linspace(0,1, 256):
+for x in np.linspace(0,1, 256):
     rcol = 0.237 - 2.13*x + 26.92*x**2 - 65.5*x**3 + 63.5*x**4 - 22.36*x**5
     gcol = ((0.572 + 1.524*x - 1.811*x**2)/(1 - 0.291*x + 0.1574*x**2))**2
     bcol = 1/(1.579 - 4.03*x + 12.92*x**2 - 31.4*x**3 + 48.6*x**4 - 23.36*x**5)
@@ -77,7 +77,7 @@ cm_plusmin = matplotlib.colors.LinearSegmentedColormap.from_list("PaulT_plusmin"
 from scipy.special import erf
 
 cols = []
-for x in N.linspace(0,1, 256):
+for x in np.linspace(0,1, 256):
     rcol = (1 - 0.392*(1 + erf((x - 0.869)/ 0.255)))
     gcol = (1.021 - 0.456*(1 + erf((x - 0.527)/ 0.376)))
     bcol = (1 - 0.493*(1 + erf((x - 0.272)/ 0.309)))
@@ -87,7 +87,7 @@ cm_linear = matplotlib.colors.LinearSegmentedColormap.from_list("PaulT_linear",
 
 # Linear colormap (rainbow)
 cols = [(0,0,0)]
-for x in N.linspace(0,1, 254):
+for x in np.linspace(0,1, 254):
     rcol = (0.472-0.567*x+4.05*x**2)/(1.+8.72*x-19.17*x**2+14.1*x**3)
     gcol = 0.108932-1.22635*x+27.284*x**2-98.577*x**3+163.3*x**4-131.395*x**5+40.634*x**6
     bcol = 1./(1.97+3.54*x-68.5*x**2+243*x**3-297*x**4+125*x**5)
@@ -129,3 +129,21 @@ phase_colors_dict['warm'] = hsv_to_rgb(hsv)
 pressure_colors_dict['total'] = hsv_to_rgb(hsv)
 phase_colors_dict['wim'] = hsv_to_rgb(hsv)
 
+my_qualitative_colors = [
+    phase_colors_dict['cold'],
+    phase_colors_dict['warm'],
+    phase_colors_dict['hot'],
+    phase_colors_dict['all'],
+    pressure_colors_dict['cr'],
+    pressure_colors_dict['bulk'],
+]
+
+my_orange = rgb_to_hsv((
+    np.array(hex2color(my_qualitative_colors[1])) + 
+    np.array(hex2color(my_qualitative_colors[2])))/2)
+
+my_orange[-2]*=1.4
+my_orange[-1]*=1.1
+
+my_qualitative_colors+=[hsv_to_rgb(my_orange) ]
+
